pub struct UnivariatePoly<F>(/* private fields */);Expand description
Univariate polynomial in coefficient form.
Implementations
Sourceimpl<F> UnivariatePoly<F>
impl<F> UnivariatePoly<F>
Sourceimpl<F: Field> UnivariatePoly<F>
impl<F: Field> UnivariatePoly<F>
pub fn eval_at_point<EF: ExtensionField<F>>(&self, x: EF) -> EF
Sourceimpl<F: Field> UnivariatePoly<F>
impl<F: Field> UnivariatePoly<F>
pub fn lagrange_interpolate<BF: Field>(points: &[BF], evals: &[F]) -> Selfwhere
F: ExtensionField<BF>,
Sourceimpl<F: TwoAdicField> UnivariatePoly<F>
impl<F: TwoAdicField> UnivariatePoly<F>
Sourcepub fn from_evals(evals: &[F]) -> Self
pub fn from_evals(evals: &[F]) -> Self
Constructs the polynomial in coefficient form from its evaluations on
{omega^0,...,omega^d} where d is the degree of the polynomial. Here omega is a
(fixed) generator of the two-adic subgroup of order (d+1).next_power_of_two().
Sourcepub fn from_evals_idft(evals: &[F]) -> Self
pub fn from_evals_idft(evals: &[F]) -> Self
Constructs the polynomial in coefficient form from its evaluations on a smooth subgroup of
F^* by performing inverse DFT.
Requires that evals.len() is a power of 2.
Sourcepub fn from_geometric_cosets_evals_idft<BF: Field>(
evals: RowMajorMatrix<F>,
shift: BF,
init: BF,
) -> Selfwhere
F: ExtensionField<BF>,
pub fn from_geometric_cosets_evals_idft<BF: Field>(
evals: RowMajorMatrix<F>,
shift: BF,
init: BF,
) -> Selfwhere
F: ExtensionField<BF>,
Interpolates from evaluations on cosets init * g^i D for i = 0,..,width-1 where D is
a smooth subgroup of F.